crt: tls: Rename __mingw_TLScallback_ptr to __w64_mingwthr_callback_ptr

It is a better description of the callback which is used for w64_mingwthr API functionality.

Signed-off-by: LIU Hao <lh_mouse@126.com>
diff --git a/mingw-w64-crt/crt/tlsthrd_register.c b/mingw-w64-crt/crt/tlsthrd_register.c
index 299660b..4797328 100644
--- a/mingw-w64-crt/crt/tlsthrd_register.c
+++ b/mingw-w64-crt/crt/tlsthrd_register.c
@@ -10,9 +10,9 @@
 #include <windows.h>
 #include <sect_attribs.h>
 
-const int __mingw_TLScallback_caller_provider = 1;
-extern void (WINAPI *const __mingw_TLScallback_ptr)(HANDLE,DWORD,LPVOID);
-static void WINAPI tls_callback(HANDLE handle, DWORD reason, LPVOID reserved) { __mingw_TLScallback_ptr(handle, reason, reserved); }
+const int __w64_mingwthr_callback_caller_provider = 1;
+extern void (WINAPI *const __w64_mingwthr_callback_ptr)(HANDLE,DWORD,LPVOID);
+static void WINAPI tls_callback(HANDLE handle, DWORD reason, LPVOID reserved) { __w64_mingwthr_callback_ptr(handle, reason, reserved); }
 static _CRTALLOC(".CRT$XLD") const PIMAGE_TLS_CALLBACK tls_callback_ptr = tls_callback;
 
 /* Force tlssup.c (_tls_used symbol for .tls linker section) to be linked.  */
diff --git a/mingw-w64-crt/crt/crtdll.c b/mingw-w64-crt/crt/crtdll.c
index 31a137f..ecabf67 100644
--- a/mingw-w64-crt/crt/crtdll.c
+++ b/mingw-w64-crt/crt/crtdll.c
@@ -29,8 +29,8 @@
 /* TLS initialization hook.  */
 const PIMAGE_TLS_CALLBACK __dyn_tls_init_callback __attribute__((common)); /* tentative */
 
-void (WINAPI *const __mingw_TLScallback_ptr)(HANDLE,DWORD,LPVOID) __attribute__((common)); /* tentative */
-const int __mingw_TLScallback_caller_provider = 1; /* crtdll.c calls __mingw_TLScallback_ptr */
+void (WINAPI *const __w64_mingwthr_callback_ptr)(HANDLE,DWORD,LPVOID) __attribute__((common)); /* tentative */
+const int __w64_mingwthr_callback_caller_provider = 1; /* crtdll.c calls __w64_mingwthr_callback_ptr */
 
 WINBOOL (WINAPI *const __mingw_atexit_tls_callback_ptr)(HANDLE,DWORD,LPVOID) __attribute__((common)); /* tentative */
 const int __mingw_atexit_tls_callback_caller_provider = 1; /* crtdll.c calls __mingw_atexit_tls_callback_ptr */
@@ -77,8 +77,8 @@
 	  __native_startup_state = __initializing;
 	  
 	  _pei386_runtime_relocator ();
-	  if (__mingw_TLScallback_ptr != NULL)
-	    __mingw_TLScallback_ptr (hDllHandle, dwReason, lpreserved);
+	  if (__w64_mingwthr_callback_ptr != NULL)
+	    __w64_mingwthr_callback_ptr (hDllHandle, dwReason, lpreserved);
 	  if (__mingw_dll_atexit_table_func_ptr != NULL)
 	    {
 	      ret = __mingw_dll_atexit_table_func_ptr (0 /*init*/);
@@ -140,8 +140,8 @@
 	}
       else
 	{
-	  if (__mingw_TLScallback_ptr != NULL)
-	    __mingw_TLScallback_ptr (hDllHandle, dwReason, lpreserved);
+	  if (__w64_mingwthr_callback_ptr != NULL)
+	    __w64_mingwthr_callback_ptr (hDllHandle, dwReason, lpreserved);
 	  if (__mingw_atexit_tls_callback_ptr != NULL)
 	    __mingw_atexit_tls_callback_ptr (hDllHandle, dwReason, lpreserved);
 	  if (__mingw_dll_atexit_table_func_ptr != NULL)
@@ -161,8 +161,8 @@
     }
   else if (dwReason == DLL_THREAD_DETACH)
     {
-      if (__mingw_TLScallback_ptr != NULL)
-	 __mingw_TLScallback_ptr (hDllHandle, dwReason, lpreserved);
+      if (__w64_mingwthr_callback_ptr != NULL)
+	 __w64_mingwthr_callback_ptr (hDllHandle, dwReason, lpreserved);
       if (__mingw_atexit_tls_callback_ptr != NULL)
 	{
 	  if (! __mingw_atexit_tls_callback_ptr (hDllHandle, dwReason, lpreserved))
diff --git a/mingw-w64-crt/crt/tlsthrd.c b/mingw-w64-crt/crt/tlsthrd.c
index ce7ed3b..11594db 100644
--- a/mingw-w64-crt/crt/tlsthrd.c
+++ b/mingw-w64-crt/crt/tlsthrd.c
@@ -166,8 +166,8 @@
       break;
     }
 }
-void (WINAPI *const __mingw_TLScallback_ptr)(HANDLE,DWORD,LPVOID) = __mingw_TLScallback;
+void (WINAPI *const __w64_mingwthr_callback_ptr)(HANDLE,DWORD,LPVOID) = __mingw_TLScallback;
 
-/* Force inclusion of code which calls __mingw_TLScallback */
-extern const int __mingw_TLScallback_caller_provider;
-static __attribute__ ((used)) const void *const _include_mingw_TLScallback_caller = &__mingw_TLScallback_caller_provider;
+/* Force inclusion of code which calls __w64_mingwthr_callback_ptr */
+extern const int __w64_mingwthr_callback_caller_provider;
+static __attribute__ ((used)) const void *const _include_w64_mingwthr_callback_caller = &__w64_mingwthr_callback_caller_provider;